# Installation

## Dependencies

Pug requires python >= 2.7 and all the modules mentioned in requirements.txt, including some that are distribution-specific (i.e require `yum` or `apt-get` before `pip`).

### On Ubuntu >= 9.04

To install `pug` and it's dependencies...

    apt-get install pip
    pip install pug
